# en.pm - The Object Class that provides a English Language Object
# Created by James A. Pattie, 11/07/2000.

# Copyright (c) 2000-2004, Xperience, Inc. http://www.pcxperience.com/
# All rights reserved.  This program is free software; you can redistribute it
# and/or modify it under the same terms as Perl itself.

package Portal::Example::Language::en;
use strict;
use Portal::LanguageBase;
use vars qw($AUTOLOAD $VERSION @ISA @EXPORT);

require Exporter;

@ISA = qw(Portal::LanguageBase Exporter AutoLoader);
@EXPORT = qw();

$VERSION = '0.01';

# The Phrases used by the App.  - Add these to the Template and convert in each language as created.

my %phrases = {};
$phrases{stateNeeded} = "The State of the Application must be specified!";
$phrases{commandNeeded} = "The Command to execute must be specified!";
$phrases{sessionCookieNeeded} = "The Session Cookie must be defined!";
$phrases{sessionNotCreated} = "The Session does not exist but Session Cookie is defined!";
$phrases{commandNotKnown} = "Command = '%s' is not known!";
$phrases{stateNotKnown} = "State = '%s' is not known!";
$phrases{stateEvalFailed} = "Eval of State = '%s' failed!<br>\nError = '%s'.";
$phrases{appStateCommand} = "App = '%s', State = '%s', Command = '%s'.";
$phrases{close} = "Close App";
$phrases{help} = "Help";
$phrases{appVersion} = "Example Version = <font color=\"%s\">%s</font>";
$phrases{refresh} = "Refresh";
$phrases{title} = "Portal Example %s - %s";
$phrases{mainMenu} = "Main Menu";
$phrases{closeMessage} = "Press 'OK' if you really want to Close this Application,\\nelse press 'Cancel'.";
$phrases{helloWorld} = "Hello World!";
$phrases{error} = "Error";
$phrases{status} = "Status";
$phrases{lock} = "Lock";
$phrases{unlock} = "Un-Lock";
$phrases{allUsers} = "All Users";
$phrases{selectedUsers} = "Selected Users";
$phrases{specificCompany} = "Specific Company";
$phrases{breakLock} = "Break Lock";
$phrases{appNotAssigned} = "You do not have this application assigned to you";
$phrases{notAdminLockMessage} = "You are not an administrator so you can not lock/unlock this app";
$phrases{errorExclam} = "Error!";
$phrases{missingArgument} = "<b>%s</b> is missing";
$phrases{invalidArgument} = "<b>%s</b> = '%s' is invalid";

# new
# instantiates an instance of the English Language Phrases.
sub new
{
  my $class = shift;
  my $self = $class->SUPER::new(@_);
  my %args = (  @_ );

  if ($self->error)
  {
    $self->prefixError();
    return $self;
  }

  $self->{phrases} = { %phrases };
  $self->{encoding} = "iso-8859-1";

  # do validation
  if (!$self->isValid())
  {
    return $self;
  }

  return $self;
}

1;
__END__

=head1 NAME

en - Object used to build a English Object Class.

=head1 SYNOPSIS

  use Portal::Example::Language::en;
  my $obj = Portal::Example::Language::en->new;
  if ($obj->error())
  {
    die $obj->errorMessage();
  }

=head1 DESCRIPTION

en is a English class.

=head1 Exported FUNCTIONS

  scalar new(void)
    Creates a new instance of the Portal::Example::Language::en
    object.

=head1 Exported VARIABLES

  hash   phrases  - converted phrases
  scalar encoding - content type encoding for document.

  NOTE:  All data fields are accessible by specifying the object
         and pointing to the data member to be modified on the
         left-hand side of the assignment.
         Ex.  $obj->variable($newValue); or $value = $obj->variable;

=head1 AUTHOR

Xperience, Inc. (mailto:admin@pcxperience.com)

=head1 SEE ALSO

perl(1), Portal(3), Portal::Example(3)

=cut
